@@ -69,7 +69,12 @@ def _inner_buffers(save_state):
 def _outer_buffers(state):
     assert type(state) is State
     is_save_state = lambda x: isinstance(x, SaveState)
+    # state.save_state has type PyTree[SaveState]. In particular this may include some
+    # `None`s, which may sometimes be treated as leaves (e.g.
+    # `tree_at(_outer_buffers, ..., is_leaf=lambda x: x is None)`).
+    # So we need to only get those leaves which really are a SaveState.
     save_states = jtu.tree_leaves(state.save_state, is_leaf=is_save_state)
+    save_states = [x for x in save_states if is_save_state(x)]
     return (
         [s.ts for s in save_states]
         + [s.ys for s in save_states]
@@ -142,7 +147,7 @@ def loop(
 
     # Privileged optimisation for the common case of no jumps. We can reduce
     # solver compile time with this.
-    # TODO: somehow make this a non-priviliged optimisation, i.e. detect when
+    # TODO: somehow make this a non-privileged optimisation, i.e. detect when
     # we can make jumps or not.
     cannot_make_jump = isinstance(stepsize_controller, (ConstantStepSize, StepTo)) or (
         isinstance(stepsize_controller, PIDController)
