@@ -1,7 +1,7 @@
 import numpy as np
 
 from ..local_interpolation import ThirdOrderHermitePolynomialInterpolation
-from .base import AbstractAdaptiveSDESolver, AbstractStratonovichSolver
+from .base import AbstractStratonovichSolver
 from .runge_kutta import AbstractERK, ButcherTableau
 
 
@@ -13,7 +13,7 @@ _midpoint_tableau = ButcherTableau(
 )
 
 
-class Midpoint(AbstractERK, AbstractStratonovichSolver, AbstractAdaptiveSDESolver):
+class Midpoint(AbstractERK, AbstractStratonovichSolver):
     """Midpoint method.
 
     2nd order explicit Runge--Kutta method. Has an embedded Euler method for adaptive
