@@ -1,7 +1,7 @@
 import numpy as np
 
 from ..local_interpolation import ThirdOrderHermitePolynomialInterpolation
-from .base import AbstractAdaptiveSDESolver, AbstractStratonovichSolver
+from .base import AbstractStratonovichSolver
 from .runge_kutta import AbstractERK, ButcherTableau
 
 
@@ -22,11 +22,13 @@ _ralston_tableau = ButcherTableau(
 )
 
 
-class Ralston(AbstractERK, AbstractStratonovichSolver, AbstractAdaptiveSDESolver):
+class Ralston(AbstractERK, AbstractStratonovichSolver):
     """Ralston's method.
 
     2nd order explicit Runge--Kutta method. Has an embedded Euler method for adaptive
     step sizing.
+
+    When used to solve SDEs, converges to the Stratonovich solution.
     """
 
     tableau = _ralston_tableau
